module Quilt
  module UIHelper
    cattr_accessor :render_fallback
    cattr_accessor :logger_callback

    self.render_fallback = false

    def self.comment_wrapping!
      include(CommentWrapping)
    end

    module CommentWrapping
      extend ActiveSupport::Concern

      included do
        instance_methods.each do |method_name|
          next unless method_name.to_s.starts_with?('ui_')

          original_ui_method = instance_method(method_name)

          define_method(method_name) do |*args, &block|
            safe_join [
              "<!-- start #{method_name} -->".html_safe,
              original_ui_method.bind(self).call(*args, &block),
              "<!-- end #{method_name} -->".html_safe
            ]
          end
        end
      end
    end
  end
end
